
/**
 * Module dependencies.
 */

var express = require('express'),
    MemStore = express.session.MemoryStore,
    User = require('./user'),
    routes = require('./routes');

var app = module.exports = express.createServer();

// Configuration

app.configure(function(){
  app.set('views', __dirname + '/views');
  app.set('view engine', 'jade');
  app.use(express.bodyParser());
  app.use(express.methodOverride());
  app.use(express.static(__dirname + '/public'));
  app.use(express.cookieParser());
  app.use(express.session({ secret: 'secret_key', cookie: {maxAge: 60000 }, store: new MemStore() }));
  app.use(app.router);
});

app.configure('development', function(){
  app.use(express.errorHandler({ dumpExceptions: true, showStack: true }));
});

app.configure('production', function(){
  app.use(express.errorHandler());
});

// Routes

app.get('/', routes.index);

//Session Routes

// Create Session from Login Form Submission
app.post('/sessions', function(req, res) {
  User.authenticate(req.body, function(user) {

    if (!user || user.length == 0 || user.length > 1) {
      res.json({fail: "true"});
    } else {
      req.session.auth = {
        userID: user.id,
      };
      res.json(req.session.auth);
    }

  });
});
// Get Session
app.get('/sessions', function(req, res) {
  res.json(req.session.auth);
});
// Destroy Session
app.get('/sessions/destroy', function(req, res) {
  delete req.session.auth;
  req.session.destroy(function(err) {})
  req.sessionStore.destroy(req.sessionID, function(err, result) {
    if (err) console.log(err);
  });
  res.send();
});

app.listen(3000, function(){
  console.log("Express server listening on port %d in %s mode", app.address().port, app.settings.env);
});
